Class: Batches::ServerTimeout504

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/batches/models/server_timeout504.rb

Overview

Timeout

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(error_code: SKIP, detailed_error_code: SKIP, detailed_error_description: SKIP, additional_properties: nil) ⇒ ServerTimeout504

Returns a new instance of ServerTimeout504.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/batches/models/server_timeout504.rb', line 47

def initialize(error_code: SKIP, detailed_error_code: SKIP,
               detailed_error_description: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @error_code = error_code unless error_code == SKIP
  @detailed_error_code = detailed_error_code unless detailed_error_code == SKIP
  unless detailed_error_description == SKIP
    @detailed_error_description =
      detailed_error_description
  end
  @additional_properties = additional_properties
end

Instance Attribute Details

#detailed_error_codeDetailedErrorCode6

Unique reference to identify the error.

Returns:



18
19
20
# File 'lib/batches/models/server_timeout504.rb', line 18

def detailed_error_code
  @detailed_error_code
end

#detailed_error_descriptionString

No response from payment method provider.

Returns:

  • (String)


22
23
24
# File 'lib/batches/models/server_timeout504.rb', line 22

def detailed_error_description
  @detailed_error_description
end

#error_codeErrorCode6

This is an error indicating there was a timeout issue to another system.

Returns:



14
15
16
# File 'lib/batches/models/server_timeout504.rb', line 14

def error_code
  @error_code
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/batches/models/server_timeout504.rb', line 62

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  error_code = hash.key?('error_code') ? hash['error_code'] : SKIP
  detailed_error_code =
    hash.key?('detailed_error_code') ? hash['detailed_error_code'] : SKIP
  detailed_error_description =
    hash.key?('detailed_error_description') ? hash['detailed_error_description'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  ServerTimeout504.new(error_code: error_code,
                       detailed_error_code: detailed_error_code,
                       detailed_error_description: detailed_error_description,
                       additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/batches/models/server_timeout504.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['error_code'] = 'error_code'
  @_hash['detailed_error_code'] = 'detailed_error_code'
  @_hash['detailed_error_description'] = 'detailed_error_description'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
# File 'lib/batches/models/server_timeout504.rb', line 43

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
39
40
# File 'lib/batches/models/server_timeout504.rb', line 34

def self.optionals
  %w[
    error_code
    detailed_error_code
    detailed_error_description
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



95
96
97
98
99
100
# File 'lib/batches/models/server_timeout504.rb', line 95

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} error_code: #{@error_code.inspect}, detailed_error_code:"\
  " #{@detailed_error_code.inspect}, detailed_error_description:"\
  " #{@detailed_error_description.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



87
88
89
90
91
92
# File 'lib/batches/models/server_timeout504.rb', line 87

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} error_code: #{@error_code}, detailed_error_code: #{@detailed_error_code},"\
  " detailed_error_description: #{@detailed_error_description}, additional_properties:"\
  " #{@additional_properties}>"
end