Class: Batches::UnknownPlatformError502
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- Batches::UnknownPlatformError502
- Defined in:
- lib/batches/models/unknown_platform_error502.rb
Overview
Bad Gateway
Instance Attribute Summary collapse
-
#detailed_error_code ⇒ DetailedErrorCode5
Unique reference to identify the error.
-
#detailed_error_description ⇒ String
Authentication error—Verify and correct credentials.
-
#error_code ⇒ ErrorCode5
This is an error indicating there was an issue connecting to a partner system..
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(error_code: SKIP, detailed_error_code: SKIP, detailed_error_description: SKIP, additional_properties: nil) ⇒ UnknownPlatformError502
constructor
A new instance of UnknownPlatformError502.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(error_code: SKIP, detailed_error_code: SKIP, detailed_error_description: SKIP, additional_properties: nil) ⇒ UnknownPlatformError502
Returns a new instance of UnknownPlatformError502.
48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/batches/models/unknown_platform_error502.rb', line 48 def initialize(error_code: SKIP, detailed_error_code: SKIP, detailed_error_description: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @error_code = error_code unless error_code == SKIP @detailed_error_code = detailed_error_code unless detailed_error_code == SKIP unless detailed_error_description == SKIP @detailed_error_description = detailed_error_description end @additional_properties = additional_properties end |
Instance Attribute Details
#detailed_error_code ⇒ DetailedErrorCode5
Unique reference to identify the error.
19 20 21 |
# File 'lib/batches/models/unknown_platform_error502.rb', line 19 def detailed_error_code @detailed_error_code end |
#detailed_error_description ⇒ String
Authentication error—Verify and correct credentials.
23 24 25 |
# File 'lib/batches/models/unknown_platform_error502.rb', line 23 def detailed_error_description @detailed_error_description end |
#error_code ⇒ ErrorCode5
This is an error indicating there was an issue connecting to a partner system..
15 16 17 |
# File 'lib/batches/models/unknown_platform_error502.rb', line 15 def error_code @error_code end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/batches/models/unknown_platform_error502.rb', line 63 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. error_code = hash.key?('error_code') ? hash['error_code'] : SKIP detailed_error_code = hash.key?('detailed_error_code') ? hash['detailed_error_code'] : SKIP detailed_error_description = hash.key?('detailed_error_description') ? hash['detailed_error_description'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. UnknownPlatformError502.new(error_code: error_code, detailed_error_code: detailed_error_code, detailed_error_description: detailed_error_description, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/batches/models/unknown_platform_error502.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['error_code'] = 'error_code' @_hash['detailed_error_code'] = 'detailed_error_code' @_hash['detailed_error_description'] = 'detailed_error_description' @_hash end |
.nullables ⇒ Object
An array for nullable fields
44 45 46 |
# File 'lib/batches/models/unknown_platform_error502.rb', line 44 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 38 39 40 41 |
# File 'lib/batches/models/unknown_platform_error502.rb', line 35 def self.optionals %w[ error_code detailed_error_code detailed_error_description ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 101 |
# File 'lib/batches/models/unknown_platform_error502.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code.inspect}, detailed_error_code:"\ " #{@detailed_error_code.inspect}, detailed_error_description:"\ " #{@detailed_error_description.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
88 89 90 91 92 93 |
# File 'lib/batches/models/unknown_platform_error502.rb', line 88 def to_s class_name = self.class.name.split('::').last "<#{class_name} error_code: #{@error_code}, detailed_error_code: #{@detailed_error_code},"\ " detailed_error_description: #{@detailed_error_description}, additional_properties:"\ " #{@additional_properties}>" end |